# v0.5.1
- fix `pyproject.toml` typo

# v0.5.0
- add config `source` functionality to remove sources (except default source)
- add `pyproject.toml` edit-button functionality

# v0.4.0
- add config `source` functionality to update current sources
- add config `source` functionality to add new sources
- add `tomlkit` dependency to update ryes `config.toml` and preserve comments

# v0.3.0
- add check for rye section of `pyproject.toml` when using `trye`
- add fallback to default config section if config section not present in rye config
- add config `source` functionality to load current sources
- add config `default` functionality and tooltips
- add button `disabled` status if no project selected, enable buttons on project selection
- fix a bug that caused crash on project creation

# v0.2.2
- Fix Regex Expression in Modal Pin by prepending `r`

# v0.2.1
- Update Readme

# v0.2.0
- add `rye init` functionality (flags still missing)
- add `rye add` + `rye add --dev` functionality (flags still missing)
- add `rye build` functionality (flags still missing)
- add `rye sync` functionality (flags still missing)
- add General Tab with `Project Home Path`, `rye tools` and `rye toolchains`
- add Config Tab to change rye config (source and default functionality still missing)

# v0.1.0
- initial release
